<?php

namespace Litecms\RaffleImages\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\RaffleImages\Models\RaffleImages;

class RaffleImagesPolicy
{

    /**
     * Determine if the given user can view the raffle_images.
     *
     * @param UserPolicy $user
     * @param RaffleImages $raffle_images
     *
     * @return bool
     */
    public function view(UserPolicy $user, RaffleImages $raffle_images)
    {
        if ($user->canDo('raffle_images.raffle_images.view') && $user->isAdmin()) {
            return true;
        }

        return $raffle_images->user_id == user_id() && $raffle_images->user_type == user_type();
    }

    /**
     * Determine if the given user can create a raffle_images.
     *
     * @param UserPolicy $user
     * @param RaffleImages $raffle_images
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('raffle_images.raffle_images.create');
    }

    /**
     * Determine if the given user can update the given raffle_images.
     *
     * @param UserPolicy $user
     * @param RaffleImages $raffle_images
     *
     * @return bool
     */
    public function update(UserPolicy $user, RaffleImages $raffle_images)
    {
        if ($user->canDo('raffle_images.raffle_images.edit') && $user->isAdmin()) {
            return true;
        }

        return $raffle_images->user_id == user_id() && $raffle_images->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given raffle_images.
     *
     * @param UserPolicy $user
     * @param RaffleImages $raffle_images
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, RaffleImages $raffle_images)
    {
        return $raffle_images->user_id == user_id() && $raffle_images->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given raffle_images.
     *
     * @param UserPolicy $user
     * @param RaffleImages $raffle_images
     *
     * @return bool
     */
    public function verify(UserPolicy $user, RaffleImages $raffle_images)
    {
        if ($user->canDo('raffle_images.raffle_images.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given raffle_images.
     *
     * @param UserPolicy $user
     * @param RaffleImages $raffle_images
     *
     * @return bool
     */
    public function approve(UserPolicy $user, RaffleImages $raffle_images)
    {
        if ($user->canDo('raffle_images.raffle_images.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
