<?php

namespace Litecms\RaffleImages\Providers;

use Illuminate\Support\ServiceProvider;

class RaffleImagesServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'raffle_images');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'raffle_images');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.raffle_images', function ($app) {
            return $this->app->make('Litecms\RaffleImages\RaffleImages');
        });

                // Bind RaffleImages to repository
        $this->app->bind(
            'Litecms\RaffleImages\Interfaces\RaffleImagesRepositoryInterface',
            \Litecms\RaffleImages\Repositories\Eloquent\RaffleImagesRepository::class
        );

        $this->app->register(\Litecms\RaffleImages\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\RaffleImages\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.raffle_images'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/raffle_images.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/raffle_images')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/raffle_images')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
